# Configuring Collibra Integration
### On this page
  * [Configuring Collibra Integration](https://help.sap.com/docs/leanix/ea/configuring-collibra-integration#configuring-collibra-integration)
  * [Setting Up Authentication](https://help.sap.com/docs/leanix/ea/configuring-collibra-integration#setting-up-authentication)
  * [Basic Auth](https://help.sap.com/docs/leanix/ea/configuring-collibra-integration#basic-auth)
  * [OAuth 2.0](https://help.sap.com/docs/leanix/ea/configuring-collibra-integration#oauth-2.0)
  * [Credentials Validity](https://help.sap.com/docs/leanix/ea/configuring-collibra-integration#credentials-validity)
  * [Trigger Synchronization](https://help.sap.com/docs/leanix/ea/configuring-collibra-integration#trigger-synchronization)


Setting up the integration between SAP LeanIX and Collibra involves configuring authentication (Basic Auth or OAuth 2.0) and ensuring credentials validity for secure access.
